[![DOI](https://zenodo.org/badge/563768686.svg)](https://zenodo.org/badge/latestdoi/563768686)

# Jintegral
A Python implementation of J-integral data reduction for translaminar toughness of compact tension specimens

# Roadmap 
Currently, this repository contains only (functional) raw code as a support for paper doi: .
It will be cleaned and (hopefully) packaged for a future release. 

# Documentation
To be done

# Related works on github

- https://github.com/smrg-uob/OUR-OMA
- https://github.com/irfancn/Matlab-J-integral

# Acknowledgement

The research leading to this software has been carried out within the framework of [HyFiSyn project](https://www.hyfisyn.eu/) and has received funding from the European Union’s Horizon 2020 research and innovation programme under the Marie Skłodowska-Curie grant agreement No. 765881. 
